==> pfd_toolkit-0.3.2.tar.gz: pfd_toolkit-0.3.2/docs/contribute.md <==
# Feedback & contributions

Thank you for your interest in contributing to PFD Toolkit! We welcome input from researchers, data scientists, developers, and anyone passionate about improving access to coroners’ Prevention of Future Death reports.

---

## How you can get involved

### Report issues & bugs 

If you encounter a bug, data problem, or unexpected behaviour, please open an issue on [Github](https://github.com/Sam-Osian/PFD-toolkit/issues).

Include a clear description and, if possible, steps to reproduce, your Python version, and environment details.

---

### Suggest features or improvements 

Have an idea for a new feature, a better workflow, or an additional data cleaning/categorisation option?

Submit a feature request as a [GitHub issue](https://github.com/Sam-Osian/PFD-toolkit/issues) with as much detail as possible.

---

### Code contributions

Contributions are welcome - whether fixing bugs, adding new features, improving documentation, or expanding tests.

If your change is significant, consider opening an issue first to discuss it.

!!! note
    Code contributors should: 

    * Fork the repository on GitHub using the **Fork** button on the [repo home page](https://github.com/Sam-Osian/PFD-toolkit).
    * Clone your fork locally:

    ```bash
    git clone https://github.com/sam-osian/PFD-toolkit.git
    ```

    * [Install `uv`](https://docs.astral.sh/uv/getting-started/installation/) and sync project dependencies:

    ```bash
    uv sync
    ```

    * Create a branch for your work

    * Submit a pull request when you're ready


---

### Anything else, get in touch 💬

If you have any questions, feedback or would like to contribute in a way not outlined above, please contact Sam on samoand@liverpool.ac.uk.

==> pfd_toolkit-0.3.3.tar.gz: pfd_toolkit-0.3.3/docs/contribute.md <==
# Feedback & contributions

Thank you for your interest in contributing to PFD Toolkit! We welcome input from researchers, data scientists, developers, and anyone passionate about improving access to coroners’ Prevention of Future Death reports.

---

## How you can get involved

### Report issues & bugs 

If you encounter a bug, data problem, or unexpected behaviour, please open an issue on [Github](https://github.com/Sam-Osian/PFD-toolkit/issues).

Include a clear description and, if possible, steps to reproduce, your Python version, and environment details.

---

### Suggest features or improvements 

Have an idea for a new feature, a better workflow, or an additional data cleaning/categorisation option?

Submit a feature request as a [GitHub issue](https://github.com/Sam-Osian/PFD-toolkit/issues) with as much detail as possible.

---

### Code contributions

Contributions are welcome - whether fixing bugs, adding new features, improving documentation, or expanding tests.

If your change is significant, consider opening an issue first to discuss it.

!!! note
    Code contributors should: 

    * Fork the repository on GitHub using the **Fork** button on the [repo home page](https://github.com/Sam-Osian/PFD-toolkit).
    * Clone your fork locally:

    ```bash
    git clone https://github.com/sam-osian/PFD-toolkit.git
    ```

    * [Install `uv`](https://docs.astral.sh/uv/getting-started/installation/) and sync project dependencies, including developer-only dependencies:

    ```bash
    uv sync --dev
    ```

    * Create a branch for your work

    * Submit a pull request when you're ready


---

### Anything else, get in touch 💬

If you have any questions, feedback or would like to contribute in a way not outlined above, please contact Sam on samoand@liverpool.ac.uk.
